/******************************************************************************
* The copyright in this software is being made available under the BSD        *
* License, included below. This software may be subject to other third party  *
* and contributor rights, including patent rights, and no such rights are     *
* granted under this license.                                                 *
*    <OWNER> = ISO                                                            *
*    <ORGANIZATION> = ISO                                                     *
*    <YEAR> = 2015                                                            *
*    Copyright (c) 2012-2015, ISO                                             *
*                                                                             *
* All rights reserved.                                                        *
* Redistribution and use in source and binary forms, with or without          *
* modification, are permitted provided that the following conditions are met: *
*       * Redistributions of source code must retain the above copyright      *
*         notice,this list of conditions and the following disclaimer.        *
*       * Redistributions in binary form must reproduce the above             *
*         copyright notice, this list of conditions and the following         *
*         disclaimer in the documentation and/or other materials provided     *
*         with the distribution.                                              *
*       * Neither the name of the <ORGANIZATION> nor the names of its         *
*         contributors may be used to endorse or promote products derived     *
*         from this software without specific prior written permission.       *
*                                                                             *
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" *
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE   *
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE  *
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   *
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         *
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF        *
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    *
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN     *
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)     *
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE  *
* POSSIBILITY OF SUCH DAMAGE.                                                 *
 ******************************************************************************/

#ifndef _JH_CHECKSUM_H
#define _JH_CHECKSUM_H

#include "jh_datatypes.h"

#ifdef __cplusplus
extern "C" {
#endif

/* Before decoding, call this to determine whether the checksum stored in the Dolby APP11
 * parameter segment matches the value computed for the base image according to Appendix F.
 *
 * Returns JH_OK if checksum matches, otherwise an error is reported.
 */
extern int jh_is_checksum_valid(jh_stream_t* stream, jh_error_t* error);

/* After encoding, adds a checksum for the base image, computed according to Appendix F, to the
 * Dolby APP11 parameter segment.
 *
 * Returns JH_OK if the checksum was successfully added, otherwise an error is reported.
 */
extern int jh_add_checksum(jh_stream_t* stream, jh_error_t* error);

#ifdef __cplusplus
}
#endif

#endif
