/******************************************************************************
 * The copyright in this software is being made available under the BSD        *
 * License, included below. This software may be subject to other third party  *
 * and contributor rights, including patent rights, and no such rights are     *
 * granted under this license.                                                 *
 *    <OWNER> = ISO                                                            *
 *    <ORGANIZATION> = ISO                                                     *
 *    <YEAR> = 2015                                                            *
 *    Copyright (c) 2012-2015, ISO                                             *
 *                                                                             *
 * All rights reserved.                                                        *
 * Redistribution and use in source and binary forms, with or without          *
 * modification, are permitted provided that the following conditions are met: *
 *       * Redistributions of source code must retain the above copyright      *
 *         notice,this list of conditions and the following disclaimer.        *
 *       * Redistributions in binary form must reproduce the above             *
 *         copyright notice, this list of conditions and the following         *
 *         disclaimer in the documentation and/or other materials provided     *
 *         with the distribution.                                              *
 *       * Neither the name of the <ORGANIZATION> nor the names of its         *
 *         contributors may be used to endorse or promote products derived     *
 *         from this software without specific prior written permission.       *
 *                                                                             *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" *
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE   *
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE  *
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   *
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         *
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF        *
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    *
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN     *
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)     *
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE  *
 * POSSIBILITY OF SUCH DAMAGE.                                                 *
 ******************************************************************************/

#ifndef _JH_COLOR_H
#define _JH_COLOR_H

#ifdef __cplusplus
extern "C" {
#endif

#include "jh_trc_data.h"

#define JH_CS_MATRIX_SIZE 9       /* 3x3 RGB -> XYZ matrix */

    /* Provide access to default color space objects */
    extern const float default_csb[JH_CS_MATRIX_SIZE];
    extern const float default_csr[JH_CS_MATRIX_SIZE];
    extern void jh_get_default_bga(float bga[JH_CS_TRC_SIZE]);  /* fill bga with default */

    /** @brief Defines the structure that holds the objects required for converting
     * 8-bit base image RGB values to HDR linear RGB destination color space, as thus:
     *     d = conv_matrix * base_trc[RGB_s]
     */
    typedef struct jh_colorconvert_params_ts {
        float base_trc[JH_CS_TRC_SIZE];             /* bga: base colorspace's gamma-encoded to linear RGB LUT */
        float conv_matrix[JH_CS_MATRIX_SIZE];       /* csb: matrix converting base linear RGB to HDR RGB      */
    } jh_colorconvert_params_t;
    

    /* sets csp->matrix_product = inverse(dest_rgb_cs_mat_3x3) * Mat_sRGB and csp->TRC = a sampled version of the sRGB TRC.
     * returns 0 on success, 1 on failure (if the matrix dest_rgb_cs_mat_3x3 is singular)
     */
    extern int jh_init_colorconvert_params(jh_colorconvert_params_t *csp,
                                           const float *cs_conv_mat,
                                           const float *base_trc);

    /* convert an 8-bit sRGB pixel to destination linear RGB float value */
    extern void jh_baseRGB_to_hdrRGB(const unsigned char *s,
                                     float *d,
                                     const jh_colorconvert_params_t* csp);
    
    /* convert RGB to Y using specified coeffients (typically the first 3 elements of inverse(csr)).
       If coefs == NULL, default REC 601 coefficients are used. */
    extern float jh_hdr_lum(const float R, const float G, const float B, const float *coefs);

#ifdef __cplusplus
}
#endif

#endif
